Estimate the neighbor size by mean-variance normalized bimodality coefficient
when config["doubletfinder"]["findpK"] set true. Display the distribution of
pANNs and visualize doublet predictions in cell clusters.

